@@ -6,7 +6,7 @@ def s_label(scanner, token):
 
 
 def s_condition(scanner, token):
-    return ('condition', token[:-1])
+    return ('condition', token)
 
 
 def s_register(scanner, token):
@@ -33,10 +33,6 @@ def s_if(scanner, token):
     return ('if', token)
 
 
-def s_cond(scanner, token):
-    return ('cond', token)
-
-
 def s_whitespace(scanner, token):
     return
 
